All Classes
-
Annotation Types Summary Class Description ConfigurationProperty The metadata annotation used to declare on the Java field whose modifiers usually are static and final for the configuration property.Experimental The marker annotation indicates a feature is experimental, it could be changed or even be removed in the future.Immutable Marker annotation to indicate that the annotated element is immutable, this means that its state cannot be seen to change by callers.Nonnull A common Microsphere annotation to declare that annotated elements cannot benull.Nullable A common Microsphere annotation to declare that annotated elements can benullunder some circumstance.Since The annotation that indicates the API is introduced in the first time.