Package io.microsphere.annotation.concurrent
-
Annotation Types Summary Annotation Type Description NotThreadSafe The class to which this annotation is applied is not thread-safe.ThreadSafe The class to which this annotation is applied is thread-safe.