A C D E I M N R S T V
All Classes All Packages
All Classes All Packages
All Classes All Packages
A
- APPLICATION_SOURCE - Static variable in annotation type io.microsphere.annotation.ConfigurationProperty
-
Application
C
- ConfigurationProperty - Annotation Type in io.microsphere.annotation
-
The metadata annotation used to declare on the Java field whose modifiers usually are static and final for the configuration property.
D
- defaultValue() - Method in annotation type io.microsphere.annotation.ConfigurationProperty
-
The default value of the configuration property.
- description() - Method in annotation type io.microsphere.annotation.ConfigurationProperty
-
The description of the configuration property.
- description() - Method in annotation type io.microsphere.annotation.Experimental
-
The description of the experimental feature
E
- ENVIRONMENT_VARIABLES_SOURCE - Static variable in annotation type io.microsphere.annotation.ConfigurationProperty
-
OS Environment Variables
- Experimental - Annotation Type in io.microsphere.annotation
-
The marker annotation indicates a feature is experimental, it could be changed or even be removed in the future.
I
- Immutable - Annotation Type in io.microsphere.annotation
-
Marker annotation to indicate that the annotated element is immutable, this means that its state cannot be seen to change by callers.
- io.microsphere.annotation - package io.microsphere.annotation
M
N
- name() - Method in annotation type io.microsphere.annotation.ConfigurationProperty
-
The name of the configuration property.
- Nonnull - Annotation Type in io.microsphere.annotation
-
A common Microsphere annotation to declare that annotated elements cannot be
null. - Nullable - Annotation Type in io.microsphere.annotation
-
A common Microsphere annotation to declare that annotated elements can be
nullunder some circumstance.
R
- required() - Method in annotation type io.microsphere.annotation.ConfigurationProperty
-
Whether the configuration property is required.
S
- Since - Annotation Type in io.microsphere.annotation
-
The annotation that indicates the API is introduced in the first time.
- source() - Method in annotation type io.microsphere.annotation.ConfigurationProperty
-
The source of the configuration property.
- SYSTEM_PROPERTIES_SOURCE - Static variable in annotation type io.microsphere.annotation.ConfigurationProperty
-
JDK System Properties
T
- type() - Method in annotation type io.microsphere.annotation.ConfigurationProperty
-
The type of the configuration property.
V
A C D E I M N R S T VAll Classes All Packages